@@ -24,6 +24,7 @@ import hashlib
 
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
+from django.conf import settings
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -32,11 +33,18 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-TEMPLATES_DIR_PATH = os.path.abspath(
-    os.path.join('.', 'templates'))
+if hasattr(settings, 'TEMPLATES'):
+    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
+else:
+    TEMPLATES_DIR_PATH = os.path.abspath(
+        os.path.join('.', 'templates'))
 
-STATIC_DIT_PATH = os.path.abspath(
-    os.path.join('.', 'static'))
+if settings.DEBUG:
+    if hasattr(settings, 'STATICFILES_DIRS'):
+        STATIC_DIT_PATH = settings.STATICFILES_DIRS[0]
+    else:
+        STATIC_DIT_PATH = os.path.abspath(
+            os.path.join('.', 'static'))
 
 FIXTURES_DIT_PATH = os.path.abspath(
     os.path.join('.', 'fixtures'))
@@ -58,7 +66,7 @@ class Command(BaseCommand):
                 "You must specify a folder to get template."
                 )
 
-        dst = args[0]
+        
 
         if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
@@ -81,33 +89,43 @@ class Command(BaseCommand):
         logger.info("-----Start copy templates-----")
         for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
             for file in files:
-                path = 'templates/%s' % file
+                path = os.path.join(root, file)
+                dst = "./templates/%s" % file
                 logger.info("Zip " + path)
-                zip.write(path)
+                zip.write(path, dst)
+                
+        index = len(TEMPLATES_DIR_PATH) + 1
         for root, dirs, files in os.walk(STATIC_DIT_PATH):
-            staticPath = root[root.index('static'):]
             for file in files:
-                path = '%s/%s' % (staticPath, file)
+                path = os.path.join(root, file)
+                dst = "./static/%s" % path[index:]
                 logger.info("Zip " + path)
-                zip.write(path)
+                zip.write(path, dst)
         for root, dirs, files in os.walk(FIXTURES_DIT_PATH):
             for file in files:
                 path = 'fixtures/%s' % file
                 logger.info("Zip " + path)
                 zip.write(path)
                 
-        temp = get_template('py/setup.py')
+        temp = get_template('boilerplate/py/setup.py')
         content = temp.render()
         with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'w') as f:
             f.write(content)
+            
+        temp = get_template('boilerplate/txt/README.txt')
+        content = temp.render()
+        with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
+            f.write(content)
 
         zip.write('./README.txt')
         logger.info("Zip README.txt")
+        
         zip.write('./setup.py')
         logger.info("Zip setup.py")
 
         zip.close()
 
+        dst = args[0]
 
         zip = zipfile.ZipFile(
             os.path.join(dst, '%s.zip' % data['upc']), mode='w')
@@ -122,5 +140,17 @@ class Command(BaseCommand):
         zip.write('template.zip')
         zip.close()
         
-
+        if os.path.exists(FIXTURES_DIT_PATH):
+            shutil.rmtree(FIXTURES_DIT_PATH)
+        if os.path.exists(IMAGES_DIT_PATH):
+            shutil.rmtree(IMAGES_DIT_PATH)
+        if os.path.isfile('./README.txt'):
+            os.remove('./README.txt')
+        if os.path.isfile('./setup.py'):
+            os.remove('./setup.py')
+        if os.path.isfile('./info.json'):
+            os.remove('./info.json')
+        if os.path.isfile('./template.zip'):
+            os.remove('./template.zip')
+        
         logger.info('-----All OK!-----')
\ No newline at end of file
