@@ -27,6 +27,7 @@ from django.test.client import RequestFactory
 from django.db import transaction
 from django.template.loader import get_template
 from django.template import Context
+from django.conf import settings
 
 from djangocms_text_ckeditor.cms_plugins import TextPlugin
 from cms.templatetags.cms_tags import *
@@ -46,11 +47,27 @@ os.chdir('.')
 ROOT_DIR_PATH = os.path.abspath(
     os.path.join('.'))
     
-STATIC_DIT_PATH = os.path.abspath(
-    os.path.join('.', 'static'))
+if hasattr(settings, 'TEMPLATES'):
+    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
+else:
+    TEMPLATES_DIR_PATH = os.path.abspath(
+        os.path.join('.', 'templates'))
     
-TEMPLATES_DIR_PATH = os.path.abspath(
-    os.path.join('.', 'templates'))
+if settings.DEBUG:
+    if hasattr(settings, 'STATICFILES_DIRS'):
+        STATIC_DIT_PATH = settings.STATICFILES_DIRS[0]
+    else:
+        STATIC_DIT_PATH = os.path.abspath(
+            os.path.join('.', 'static'))
+else:
+    if hasattr(settings, 'STATIC_ROOT'):
+        STATIC_DIT_PATH = settings.STATIC_ROOT
+    else:
+        STATIC_DIT_PATH = os.path.abspath(
+            os.path.join('.', 'static'))
+            
+FIXTURES_DIT_PATH = os.path.abspath(
+    os.path.join('.', 'fixtures'))
 
 jsPath = os.path.join(STATIC_DIT_PATH, 'js', 'FixTemplate.js')
 
@@ -231,6 +248,12 @@ class Command(BaseCommand):
         if not os.path.exists(os.path.join(STATIC_DIT_PATH, 'js')):
             os.mkdir(os.path.join(STATIC_DIT_PATH, 'js'))
             
+        if not os.path.exists(FIXTURES_DIT_PATH):
+            os.mkdir(FIXTURES_DIT_PATH)
+            with open(
+                os.path.join(FIXTURES_DIT_PATH, '__init__.py'), 'w') as f:
+                pass
+            
         if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
                 data = json.load(jsonfile)
